@@ -36,7 +36,8 @@
 #' @include date-ranges.R
 #' @include report.R
 #' @export
-get_ga <- function(profile.id = NULL, start.date = "7daysAgo", end.date = "yesterday",
+get_ga <- function(profile.id = getOption("rga.profile.id"),
+                   start.date = "7daysAgo", end.date = "yesterday",
                    metrics = c("ga:users", "ga:sessions"," ga:pageviews"), dimensions = NULL,
                    sort = NULL, filters = NULL, segment = NULL, sampling.level = NULL,
                    start.index = NULL, max.results = NULL, include.empty.rows = NULL,
@@ -51,9 +52,6 @@ get_ga <- function(profile.id = NULL, start.date = "7daysAgo", end.date = "yeste
                          sampling.level = sampling.level,
                          include.empty.rows = tolower(include.empty.rows),
                          start.index = start.index, max.results = max.results)
-    if (is.null(fetch.by))
-        res <- get_report("data/ga", query, token)
-    else
-        res <- fetch_by("data/ga", query, fetch.by, token)
+    res <- get_report("data/ga", query, token, fetch.by)
     return(res)
 }
