@@ -28,7 +28,8 @@
 #' @include date-ranges.R
 #' @include report.R
 #' @export
-get_mcf <- function(profile.id = NULL, start.date = "7daysAgo", end.date = "yesterday",
+get_mcf <- function(profile.id = getOption("rga.profile.id"),
+                    start.date = "7daysAgo", end.date = "yesterday",
                     metrics = "mcf:totalConversions", dimensions = NULL,
                     sort = NULL, filters = NULL, sampling.level = NULL,
                     start.index = NULL, max.results = NULL, fetch.by = NULL, token) {
@@ -38,9 +39,6 @@ get_mcf <- function(profile.id = NULL, start.date = "7daysAgo", end.date = "yest
                          metrics = metrics, dimensions = dimensions, sort = sort, filters = filters,
                          sampling.level = sampling.level,
                          start.index = start.index, max.results = max.results)
-    if (is.null(fetch.by))
-        res <- get_report("data/mcf", query, token)
-    else
-        res <- fetch_by("data/mcf", query, fetch.by, token)
+    res <- get_report("data/mcf", query, token, fetch.by)
     return(res)
 }
