@@ -1,12 +1,13 @@
 context("Convert Core Reporting API response")
 
 ga_data <- structure(list(
-    totalResults = 8L, containsSampledData = FALSE,
-    columnHeaders = structure(list(
+    kind = "analytics#gaData",
+    total.results = 8L, contains.sampled.data = FALSE,
+    column.headers = structure(list(
         name = c("ga:date", "ga:users", "ga:sessions", "ga:pageviews"),
-        columnType = c("DIMENSION", "METRIC", "METRIC", "METRIC"),
-        dataType = c("STRING", "INTEGER", "INTEGER", "INTEGER")),
-        .Names = c("name", "columnType", "dataType"),
+        column.type = c("DIMENSION", "METRIC", "METRIC", "METRIC"),
+        data.type = c("STRING", "INTEGER", "INTEGER", "INTEGER")),
+        .Names = c("name", "column.type", "data.type"),
         class = "data.frame",
         row.names = c(NA, 4L)),
     rows = structure(c(
@@ -16,9 +17,9 @@ ga_data <- structure(list(
         "2159", "2038", "2345", "2866", "3066", "462", "4045", "4557",
         "4856", "5024", "5791", "7134", "7381", "1167"),
         .Dim = c(8L, 4L))),
-    .Names = c("totalResults", "containsSampledData", "columnHeaders", "rows"))
+    .Names = c("kind", "total.results", "contains.sampled.data", "column.headers", "rows"))
 
-ga_df <- suppressMessages(build_df(type = "ga", ga_data))
+ga_df <- build_df(ga_data)
 
 test_that("Result class", {
     expect_is(ga_df, "data.frame")
